@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # coding: utf-8
 
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
-from joker.redis.error import ErrorInterface
+from joker.redis.loggers import ErrorInterface, RedisHandler
 from joker.redis.extended import RedisExtended
